@@ -1,6 +1,6 @@
 /* request.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2025 Ralf Hoffmann.
+ * Copyright (C) 2001-2026 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -420,7 +420,7 @@ int Requester::request( const char *title,
                             case XK_Return: {
 #ifdef ACCEPT_ENTER_FOR_CHOOSE
                                 for ( size_t r = 0; r < buttons.size(); r++ ) {
-                                    for ( size_t c = 0; c < (size_t)max_buttons_per_row; r++ ) {
+                                    for ( size_t c = 0; c < (size_t)max_buttons_per_row; c++ ) {
                                         if ( c >= buttons[r].size() ) continue;
                                         if ( buttons[r][c].first == nullptr ) continue;
                                         if ( buttons[r][c].first->getHasFocus() == true ) {
@@ -504,14 +504,14 @@ int Requester::string_request( const char *title, const char *text, const char *
 
 int Requester::string_request( const char *title, const char *text, const char *default_str, const char *buttons,char **return_str, const AWindow *twin, request_flags_t flags)
 {
-    request_options options;
+    const request_options options;
 
     return string_request( title, text, default_str,
                            buttons, return_str, twin, flags, options );
 }
 
 int Requester::string_request( const char *title, const char *text, const char *default_str, const char *buttons,char **return_str, const AWindow *twin, request_flags_t flags,
-                               struct request_options &options )
+                               const struct request_options &options )
 {
     return string_request( title, text, default_str,
                            buttons, return_str, twin, flags,
@@ -521,7 +521,7 @@ int Requester::string_request( const char *title, const char *text, const char *
 
 int Requester::string_request( const char *title, const char *text, const char *default_str, const char *buttons,
                                char **return_str, const AWindow *twin, request_flags_t flags,
-                               struct request_options &options,
+                               const struct request_options &options,
                                const std::string &help_text,
                                const std::function< std::string ( const std::string &current_input_before_cursor,
                                                                   const std::string &current_input_after_cursor ) > help_callback )
