@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2003-2024 Ralf Hoffmann.
+ * Copyright (C) 2003-2025 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -321,6 +321,7 @@ struct mytoken tokenlist[]={
   { SCROLLBUTTON_WCP, "scrollbutton" },
   { SELECTMETHOD_WCP, "selectmethod" },
   { ALTERNATIVE_WCP, "alternative" },
+  { DELAYEDCONTEXTMENU_WCP, "delayedcontextmenu" },
   { SEARCHOP_WCP, "searchop" },
   { EDITCOMMAND_WCP, "editcommand" },
   { SHOWPREVRESULTS_WCP, "showprevresults" },
@@ -488,7 +489,17 @@ struct mytoken tokenlist[]={
   { CUSTOMATTRIBUTE_WCP, "customattribute" },
   { SHOWOUTPUTCUSTOMATTRIBUTE_WCP, "showoutputcustomattribute" },
   { STARTSEARCHSTRING_WCP, "startsearchstring" },
-  { APPLYONLY_WCP, "applyonly" }
+  { APPLYONLY_WCP, "applyonly" },
+  { USESELECTEDENTRIES_WCP, "useselectedentries" },
+  { ONLYEXACTPATH_WCP, "onlyexactpath" },
+  { ALSOSELECTEXTENSION_WCP, "alsoselectextension" },
+  { CUSTOMWITHHINT_WCP, "customwithhint" },
+  { DIFFERENTSIZE_WCP, "differentsize" },
+  { SMALLER_WCP, "smaller" },
+  { OLDER_WCP, "older" },
+  { KVPENTRIES_WCP, "kvpentries" },
+  { KVPENTRY_WCP, "kvpentry" },
+  { INTERNALVIEWER_WCP, "internalviewer" }
 };
 
 ArrayList *tokenlist_sorted = NULL;
